==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/securityinsights/kotlin/inputs/ThreatIntelligenceParsedPatternTypeValueArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.securityinsights.kotlin.inputs

import com.pulumi.azurenative.securityinsights.inputs.ThreatIntelligenceParsedPatternTypeValueArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Describes threat kill chain phase entity
 * @property value Value of parsed pattern
 * @property valueType Type of the value
 */
public data class ThreatIntelligenceParsedPatternTypeValueArgs(
    public val `value`: Output<String>? = null,
    public val valueType: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.securityinsights.inputs.ThreatIntelligenceParsedPatternTypeValueArgs> {
    override fun toJava():
        com.pulumi.azurenative.securityinsights.inputs.ThreatIntelligenceParsedPatternTypeValueArgs =
        com.pulumi.azurenative.securityinsights.inputs.ThreatIntelligenceParsedPatternTypeValueArgs.builder()
            .`value`(`value`?.applyValue({ args0 -> args0 }))
            .valueType(valueType?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ThreatIntelligenceParsedPatternTypeValueArgs].
 */
@PulumiTagMarker
public class ThreatIntelligenceParsedPatternTypeValueArgsBuilder internal constructor() {
    private var `value`: Output<String>? = null

    private var valueType: Output<String>? = null

    /**
     * @param value Value of parsed pattern
     */
    @JvmName("xbfriqbiqvqayehn")
    public suspend fun `value`(`value`: Output<String>) {
        this.`value` = value
    }

    /**
     * @param value Type of the value
     */
    @JvmName("syvykrarstsstxmk")
    public suspend fun valueType(`value`: Output<String>) {
        this.valueType = value
    }

    /**
     * @param value Value of parsed pattern
     */
    @JvmName("ephhoknluqykiogc")
    public suspend fun `value`(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    /**
     * @param value Type of the value
     */
    @JvmName("wfuvutbsftmclrul")
    public suspend fun valueType(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.valueType = mapped
    }

    internal fun build(): ThreatIntelligenceParsedPatternTypeValueArgs =
        ThreatIntelligenceParsedPatternTypeValueArgs(
            `value` = `value`,
            valueType = valueType,
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/securityinsights/kotlin/inputs/ThreatIntelligenceParsedPatternTypeValueArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.securityinsights.kotlin.inputs

import com.pulumi.azurenative.securityinsights.inputs.ThreatIntelligenceParsedPatternTypeValueArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Describes threat kill chain phase entity
 * @property value Value of parsed pattern
 * @property valueType Type of the value
 */
public data class ThreatIntelligenceParsedPatternTypeValueArgs(
    public val `value`: Output<String>? = null,
    public val valueType: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.securityinsights.inputs.ThreatIntelligenceParsedPatternTypeValueArgs> {
    override fun toJava():
        com.pulumi.azurenative.securityinsights.inputs.ThreatIntelligenceParsedPatternTypeValueArgs =
        com.pulumi.azurenative.securityinsights.inputs.ThreatIntelligenceParsedPatternTypeValueArgs.builder()
            .`value`(`value`?.applyValue({ args0 -> args0 }))
            .valueType(valueType?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ThreatIntelligenceParsedPatternTypeValueArgs].
 */
@PulumiTagMarker
public class ThreatIntelligenceParsedPatternTypeValueArgsBuilder internal constructor() {
    private var `value`: Output<String>? = null

    private var valueType: Output<String>? = null

    /**
     * @param value Value of parsed pattern
     */
    @JvmName("gkxetaiaqillbeud")
    public suspend fun `value`(`value`: Output<String>) {
        this.`value` = value
    }

    /**
     * @param value Type of the value
     */
    @JvmName("uwhyoptxcfisqgjk")
    public suspend fun valueType(`value`: Output<String>) {
        this.valueType = value
    }

    /**
     * @param value Value of parsed pattern
     */
    @JvmName("xxumlboptkdmpakk")
    public suspend fun `value`(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    /**
     * @param value Type of the value
     */
    @JvmName("fvtldfjowdbydsjb")
    public suspend fun valueType(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.valueType = mapped
    }

    internal fun build(): ThreatIntelligenceParsedPatternTypeValueArgs =
        ThreatIntelligenceParsedPatternTypeValueArgs(
            `value` = `value`,
            valueType = valueType,
        )
}
